DoubleEntryLedger.CommandQueue.Supervisor (double_entry_ledger v0.1.0)

Supervises the command queue system components.

This supervisor is responsible for starting and monitoring the following child processes:

The supervisor uses the :one_for_one strategy, so if a child process terminates, only that process is restarted.

Summary

Functions

Returns a specification to start this module under a supervisor.

Starts the command queue supervisor.

Functions

child_spec(init_arg)

Returns a specification to start this module under a supervisor.

See Supervisor.

start_link(init_arg)

Starts the command queue supervisor.

Parameters

  • init_arg: Initialization argument (not used).

Returns

  • {:ok, pid} on success.
  • {:error, reason} on failure.