DoubleEntryLedger.CommandQueue.Supervisor (double_entry_ledger v0.1.0)
View SourceSupervises the command queue system components.
This supervisor is responsible for starting and monitoring the following child processes:
Registry- A unique-keyed process registry for command queue instances.DynamicSupervisor- Supervises dynamically started command queue processors.DoubleEntryLedger.CommandQueue.InstanceMonitor- Monitors and manages the lifecycle of command queue instances.
The supervisor uses the :one_for_one strategy, so if a child process terminates,
only that process is restarted.
Summary
Functions
Returns a specification to start this module under a supervisor.
Starts the command queue supervisor.
Functions
Returns a specification to start this module under a supervisor.
See Supervisor.
Starts the command queue supervisor.
Parameters
init_arg: Initialization argument (not used).
Returns
{:ok, pid}on success.{:error, reason}on failure.